==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/ImageChangeTriggerStatusFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ImageChangeTriggerStatusFluentImpl<A extends io.fabric8.openshift.api.model.ImageChangeTriggerStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.ImageChangeTriggerStatusFluent<A>{
  public ImageChangeTriggerStatusFluentImpl() {
  }
  public ImageChangeTriggerStatusFluentImpl(io.fabric8.openshift.api.model.ImageChangeTriggerStatus instance) {
    this.withFrom(instance.getFrom()); 
    this.withLastTriggerTime(instance.getLastTriggerTime()); 
    this.withLastTriggeredImageID(instance.getLastTriggeredImageID()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.ImageStreamTagReferenceBuilder from;
  private java.lang.String lastTriggerTime;
  private java.lang.String lastTriggeredImageID;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildFrom instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.ImageStreamTagReference getFrom() {
    return this.from!=null?this.from.build():null;
  }
  public io.fabric8.openshift.api.model.ImageStreamTagReference buildFrom() {
    return this.from!=null?this.from.build():null;
  }
  public A withFrom(io.fabric8.openshift.api.model.ImageStreamTagReference from) {
    _visitables.get("from").remove(this.from);
    if (from!=null){ this.from= new io.fabric8.openshift.api.model.ImageStreamTagReferenceBuilder(from); _visitables.get("from").add(this.from);} return (A) this;
  }
  public java.lang.Boolean hasFrom() {
    return this.from != null;
  }
  public A withNewFrom(java.lang.String name,java.lang.String namespace) {
    return (A)withFrom(new ImageStreamTagReference(name, namespace));
  }
  public io.fabric8.openshift.api.model.ImageChangeTriggerStatusFluent.FromNested<A> withNewFrom() {
    return new io.fabric8.openshift.api.model.ImageChangeTriggerStatusFluentImpl.FromNestedImpl();
  }
  public io.fabric8.openshift.api.model.ImageChangeTriggerStatusFluent.FromNested<A> withNewFromLike(io.fabric8.openshift.api.model.ImageStreamTagReference item) {
    return new io.fabric8.openshift.api.model.ImageChangeTriggerStatusFluentImpl.FromNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.ImageChangeTriggerStatusFluent.FromNested<A> editFrom() {
    return withNewFromLike(getFrom());
  }
  public io.fabric8.openshift.api.model.ImageChangeTriggerStatusFluent.FromNested<A> editOrNewFrom() {
    return withNewFromLike(getFrom() != null ? getFrom(): new io.fabric8.openshift.api.model.ImageStreamTagReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.ImageChangeTriggerStatusFluent.FromNested<A> editOrNewFromLike(io.fabric8.openshift.api.model.ImageStreamTagReference item) {
    return withNewFromLike(getFrom() != null ? getFrom(): item);
  }
  public java.lang.String getLastTriggerTime() {
    return this.lastTriggerTime;
  }
  public A withLastTriggerTime(java.lang.String lastTriggerTime) {
    this.lastTriggerTime=lastTriggerTime; return (A) this;
  }
  public java.lang.Boolean hasLastTriggerTime() {
    return this.lastTriggerTime != null;
  }
  
  /**
   * Method is deprecated. use withLastTriggerTime instead.
   */
  @java.lang.Deprecated
  public A withNewLastTriggerTime(java.lang.String arg0) {
    return (A)withLastTriggerTime(new String(arg0));
  }
  public java.lang.String getLastTriggeredImageID() {
    return this.lastTriggeredImageID;
  }
  public A withLastTriggeredImageID(java.lang.String lastTriggeredImageID) {
    this.lastTriggeredImageID=lastTriggeredImageID; return (A) this;
  }
  public java.lang.Boolean hasLastTriggeredImageID() {
    return this.lastTriggeredImageID != null;
  }
  
  /**
   * Method is deprecated. use withLastTriggeredImageID instead.
   */
  @java.lang.Deprecated
  public A withNewLastTriggeredImageID(java.lang.String arg0) {
    return (A)withLastTriggeredImageID(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ImageChangeTriggerStatusFluentImpl that = (ImageChangeTriggerStatusFluentImpl) o;
    if (from != null ? !from.equals(that.from) :that.from != null) return false;
    if (lastTriggerTime != null ? !lastTriggerTime.equals(that.lastTriggerTime) :that.lastTriggerTime != null) return false;
    if (lastTriggeredImageID != null ? !lastTriggeredImageID.equals(that.lastTriggeredImageID) :that.lastTriggeredImageID != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(from,  lastTriggerTime,  lastTriggeredImageID,  additionalProperties,  super.hashCode());
  }
  public class FromNestedImpl<N> extends io.fabric8.openshift.api.model.ImageStreamTagReferenceFluentImpl<io.fabric8.openshift.api.model.ImageChangeTriggerStatusFluent.FromNested<N>> implements io.fabric8.openshift.api.model.ImageChangeTriggerStatusFluent.FromNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    FromNestedImpl(io.fabric8.openshift.api.model.ImageStreamTagReference item) {
      this.builder = new io.fabric8.openshift.api.model.ImageStreamTagReferenceBuilder(this, item);
    }
    FromNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.ImageStreamTagReferenceBuilder(this);
    }
    io.fabric8.openshift.api.model.ImageStreamTagReferenceBuilder builder;
    public N and() {
      return (N) ImageChangeTriggerStatusFluentImpl.this.withFrom(builder.build());
    }
    public N endFrom() {
      return and();
    }
    
  }
  
}

==> openshift-model-5.12.1-sources.jar: io/fabric8/openshift/api/model/ImageChangeTriggerStatusFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ImageChangeTriggerStatusFluentImpl<A extends io.fabric8.openshift.api.model.ImageChangeTriggerStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.ImageChangeTriggerStatusFluent<A>{
  public ImageChangeTriggerStatusFluentImpl() {
  }
  public ImageChangeTriggerStatusFluentImpl(io.fabric8.openshift.api.model.ImageChangeTriggerStatus instance) {
    this.withFrom(instance.getFrom()); 
    this.withLastTriggerTime(instance.getLastTriggerTime()); 
    this.withLastTriggeredImageID(instance.getLastTriggeredImageID()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.ImageStreamTagReferenceBuilder from;
  private java.lang.String lastTriggerTime;
  private java.lang.String lastTriggeredImageID;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildFrom instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.ImageStreamTagReference getFrom() {
    return this.from!=null?this.from.build():null;
  }
  public io.fabric8.openshift.api.model.ImageStreamTagReference buildFrom() {
    return this.from!=null?this.from.build():null;
  }
  public A withFrom(io.fabric8.openshift.api.model.ImageStreamTagReference from) {
    _visitables.get("from").remove(this.from);
    if (from!=null){ this.from= new io.fabric8.openshift.api.model.ImageStreamTagReferenceBuilder(from); _visitables.get("from").add(this.from);} return (A) this;
  }
  public java.lang.Boolean hasFrom() {
    return this.from != null;
  }
  public A withNewFrom(java.lang.String name,java.lang.String namespace) {
    return (A)withFrom(new ImageStreamTagReference(name, namespace));
  }
  public io.fabric8.openshift.api.model.ImageChangeTriggerStatusFluent.FromNested<A> withNewFrom() {
    return new io.fabric8.openshift.api.model.ImageChangeTriggerStatusFluentImpl.FromNestedImpl();
  }
  public io.fabric8.openshift.api.model.ImageChangeTriggerStatusFluent.FromNested<A> withNewFromLike(io.fabric8.openshift.api.model.ImageStreamTagReference item) {
    return new io.fabric8.openshift.api.model.ImageChangeTriggerStatusFluentImpl.FromNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.ImageChangeTriggerStatusFluent.FromNested<A> editFrom() {
    return withNewFromLike(getFrom());
  }
  public io.fabric8.openshift.api.model.ImageChangeTriggerStatusFluent.FromNested<A> editOrNewFrom() {
    return withNewFromLike(getFrom() != null ? getFrom(): new io.fabric8.openshift.api.model.ImageStreamTagReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.ImageChangeTriggerStatusFluent.FromNested<A> editOrNewFromLike(io.fabric8.openshift.api.model.ImageStreamTagReference item) {
    return withNewFromLike(getFrom() != null ? getFrom(): item);
  }
  public java.lang.String getLastTriggerTime() {
    return this.lastTriggerTime;
  }
  public A withLastTriggerTime(java.lang.String lastTriggerTime) {
    this.lastTriggerTime=lastTriggerTime; return (A) this;
  }
  public java.lang.Boolean hasLastTriggerTime() {
    return this.lastTriggerTime != null;
  }
  
  /**
   * Method is deprecated. use withLastTriggerTime instead.
   */
  @java.lang.Deprecated
  public A withNewLastTriggerTime(java.lang.String arg0) {
    return (A)withLastTriggerTime(new String(arg0));
  }
  public java.lang.String getLastTriggeredImageID() {
    return this.lastTriggeredImageID;
  }
  public A withLastTriggeredImageID(java.lang.String lastTriggeredImageID) {
    this.lastTriggeredImageID=lastTriggeredImageID; return (A) this;
  }
  public java.lang.Boolean hasLastTriggeredImageID() {
    return this.lastTriggeredImageID != null;
  }
  
  /**
   * Method is deprecated. use withLastTriggeredImageID instead.
   */
  @java.lang.Deprecated
  public A withNewLastTriggeredImageID(java.lang.String arg0) {
    return (A)withLastTriggeredImageID(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ImageChangeTriggerStatusFluentImpl that = (ImageChangeTriggerStatusFluentImpl) o;
    if (from != null ? !from.equals(that.from) :that.from != null) return false;
    if (lastTriggerTime != null ? !lastTriggerTime.equals(that.lastTriggerTime) :that.lastTriggerTime != null) return false;
    if (lastTriggeredImageID != null ? !lastTriggeredImageID.equals(that.lastTriggeredImageID) :that.lastTriggeredImageID != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(from,  lastTriggerTime,  lastTriggeredImageID,  additionalProperties,  super.hashCode());
  }
  public class FromNestedImpl<N> extends io.fabric8.openshift.api.model.ImageStreamTagReferenceFluentImpl<io.fabric8.openshift.api.model.ImageChangeTriggerStatusFluent.FromNested<N>> implements io.fabric8.openshift.api.model.ImageChangeTriggerStatusFluent.FromNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    FromNestedImpl(io.fabric8.openshift.api.model.ImageStreamTagReference item) {
      this.builder = new io.fabric8.openshift.api.model.ImageStreamTagReferenceBuilder(this, item);
    }
    FromNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.ImageStreamTagReferenceBuilder(this);
    }
    io.fabric8.openshift.api.model.ImageStreamTagReferenceBuilder builder;
    public N and() {
      return (N) ImageChangeTriggerStatusFluentImpl.this.withFrom(builder.build());
    }
    public N endFrom() {
      return and();
    }
    
  }
  
}
